References
==========

Articles
--------
.. [Albergante2020] Albergante, L., *et al.* (2020),
   *Robust And Scalable Learning Of Complex Dataset Topologies Via Elpigraph.*,
   `2020 Entropy, 22(3), 296`.


Credits and links to other implementations
------------------------------------------

R
^
.. [ElPiGraph.R] Luca Albergante,
   `ElPiGraph.R <https://github.com/Albluca/ElPiGraph.R>`__.


MATLAB
^^^^^^
.. [ElPiGraph.M] Evgeny Mirkes, Andrei Zinovyev,
   `ElPiGraph.M <https://github.com/auranic/Elastic-principal-graphs>`__.


Python 
^^^^^^
.. [ElPiGraph.P] Louis Faure, Alexis Martin,
   `ElPiGraph.P <https://github.com/LouisFaure/ElPiGraph.P>`__.

